@@ -6,12 +6,17 @@ class Log(models.Model):
     class Category(models.TextChoices):
         RESERVE = 'reserve'
 
-    user = models.ForeignKey(
-        to=get_user_model(),
-        on_delete=models.CASCADE,
-        related_name='logs',
-        related_query_name='log'
+    user_id = models.CharField(
+        max_length=1000
     )
+
+    @property
+    def user(self):
+        try:
+            return get_user_model().objects.get(pk=self.user_id)
+        except:
+            return None
+
     category = models.CharField(max_length=1000, choices=Category.choices)
     description = models.TextField()
     reference_url = models.URLField(null=True, blank=True)
